@@ -11,7 +11,8 @@ import (
 	"github.com/sirupsen/logrus"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
-	"github.com/batchcorp/plumber/options"
+
+	"github.com/streamdal/plumber/options"
 )
 
 const (
